#  The Panthera(P.)uncia of Cybersecurity 
### Subdomain & Exploit Hunter powered by AI

## Installation
1. From PyPi - `pip3 install puncia`
2. From Source - `pip3 install .`<br>

## Usage
1. Subdomain - `puncia subdomain <domain> <output>`
2. Exploit - `puncia exploit <keyword> <output>`<br>